@@ -46,7 +46,7 @@
                                                debug = mPar$debug)
   DOY = as.numeric(format(dates,"%j"))
   J = radiation_dateStringToJulianDays(as.character(dates))
-  if(is.null(object@RelativeHumidity)) { #Estimate VP assuming that dew-point temperature is equal to Tmin
+  if(is.null(object@RelativeHumidity) || all(is.na(object@RelativeHumidity))) { #Estimate VP assuming that dew-point temperature is equal to Tmin
     rhmean = .relativeHumidityFromMinMaxTemp(tmin, tmax)
     VP = .temp2SVP(tmin) #kPA
     rhmax = rep(100, length(rhmean))
@@ -107,7 +107,7 @@
     Wsp = as.vector(Wp$WS)
     Wdp = as.vector(Wp$WD)
   } else if((!is.null(object@WindSpeed)) && (!is.null(object@WindDirection))){
-    Wp = .interpolateWindStationSeriesPoints(Xp= x, Yp =y, object@WindSpeed[,dayIndices, drop=FALSE], 
+    Wp = .interpolateWindStationSeriesPoints(Xp= x, Yp =y, object@WindSpeed[,dayIndices, drop=FALSE],
                                              object@WindDirection[,dayIndices, drop=FALSE],
                                            X = object@coords[,1],
                                            Y = object@coords[,2],
@@ -143,12 +143,140 @@
   return(df)
 }
 
+
+
+#' Interpolate daily meteorology over a landscape
+#' 
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#' 
+#' Functions to interpolate meteorological data for spatial locations (at
+#' points, grid pixels or full grids) using an object of class
+#' \code{\link{MeteorologyInterpolationData-class}}.
+#' 
+#' @details
+#' CRS projection needs to be defined for both \code{object} and
+#' \code{points}/\code{pixels}/\code{grid}. If CRS projection is different
+#' between \code{object} and \code{points}/\code{pixels}/\code{grid}, the
+#' function transforms the coordinates of
+#' \code{points}/\code{pixels}/\code{grid} to adapt them to the CRS of
+#' \code{object}.
+#' 
+#' @aliases interpolationpoints interpolationpixels interpolationgrid
+#' @param object An object of class
+#' \code{\link{MeteorologyInterpolationData-class}}.
+#' @param points An object of class
+#' \code{\link{SpatialPointsTopography-class}}.
+#' @param pixels An object of class \code{\link{SpatialPixelsTopography-class}}
+#' representing the target landscape.
+#' @param grid An object of class \code{\link{SpatialGridTopography-class}}
+#' representing the target landscape.
+#' @param dates An object of class \code{\link{Date}}. If this is \code{NULL}
+#' then all dates in \code{object} are processed.
+#' @param export If \code{export = FALSE} the result of interpolation is stored
+#' in memory. Otherwise the result is written in the disk (using the format
+#' specified in \code{exportFormat}).
+#' @param exportDir Output directory for interpolated meteorology data files
+#' (txt/rds format).
+#' @param exportFile Output file for interpolated meteorology data (netCDF
+#' format).
+#' @param exportFormat Export format for meteorological data (see
+#' \code{\link{writemeteorologypoint}}).  If format is \code{"meteoland/txt"},
+#' \code{"meteoland/rds"}, \code{"castanea/txt"} or \code{"castanea/rds"} the
+#' function tries to write one file per point in \code{exportDir}. If format is
+#' \code{"netCDF"} the function will write data to a single file specified by
+#' \code{exportFile}.
+#' @param metadataFile The name of the ascii text file that will store the meta
+#' data describing all written files.
+#' @param verbose Boolean flag to print process information.
+#' @param add Boolean flag to indicate that NetCDF exists and data should be
+#' added/replaced.
+#' @param overwrite Boolean flag to force overwriting an existing NetCDF.
+#' @return If \code{export = FALSE}, function \code{interpolationpoints}
+#' returns an object of \code{\link{SpatialPointsMeteorology-class}}. If
+#' \code{export = TRUE} files and written in the disk. For text/rds format the
+#' function returns an object of class
+#' \code{\link{SpatialPointsDataFrame-class}} containing point meta data.
+#' 
+#' If \code{export = FALSE}, function \code{interpolationpixels} returns an
+#' object of \code{\link{SpatialPixelsMeteorology-class}}, or an object of
+#' \code{\link{SpatialPixelsDataFrame-class}} if a single date is interpolated.
+#' If \code{export = TRUE}, the function writes the results in a NetCDF.
+#' 
+#' If \code{export = FALSE}, function \code{interpolationgrid} returns an
+#' object of \code{\link{SpatialGridMeteorology-class}}, or an object of
+#' \code{\link{SpatialGridDataFrame-class}} if a single date is interpolated.
+#' If \code{export = TRUE}, the function writes the results in files and a
+#' \code{data.frame} with columns 'dir' and 'filename' is returned.
+#' @author Miquel De \enc{Cáceres}{Caceres} Ainsa, CREAF
+#' @seealso \code{\link{penman}}, \code{\link{SpatialPointsTopography-class}},
+#' \code{\link{SpatialGridTopography}}, \code{\link{SpatialPixelsTopography}},
+#' \code{\link{MeteorologyInterpolationData}}
+#' @references Thornton, P.E., Running, S.W., White, M. A., 1997. Generating
+#' surfaces of daily meteorological variables over large regions of complex
+#' terrain. J. Hydrol. 190, 214–251. doi:10.1016/S0022-1694(96)03128-9.
+#' 
+#' De Caceres M, Martin-StPaul N, Turco M, Cabon A, Granda V (2018) Estimating
+#' daily meteorological data and downscaling climate models over landscapes.
+#' Environmental Modelling and Software 108: 186-196.
+#' @examples
+#' 
+#' \donttest{
+#' data(examplegridtopography)
+#' data(exampleinterpolationdata)
+#' 
+#' ####### INTERPOLATION on particular POINTS 
+#' 
+#' #Creates spatial topography points from the grid
+#' p = 1:2
+#' spt = as(examplegridtopography, "SpatialPointsTopography")[p]
+#' 
+#' #Interpolation of two points for the whole time period (2000-2003)
+#' mp = interpolationpoints(exampleinterpolationdata, spt)
+#' 
+#' #Plot interpolated meteorological series
+#' meteoplot(mp,1, ylab="Mean temperature")
+#' 
+#' ####### INTERPOLATION on PIXELS 
+#' # Creates spatial topography pixels as a subset of grid pixels
+#' # and select pixels at maximum distance of 2km from center
+#' spt = as(examplegridtopography,"SpatialPointsTopography")
+#' cc = spt@coords
+#' center = 5160
+#' d = sqrt((cc[,1]-cc[center,1])^2+(cc[,2]-cc[center,2])^2)
+#' spxt = as(spt[which(d<2000)], "SpatialPixelsTopography") 
+#' 
+#' # Interpolation of meteorology over pixels for two days
+#' ml = interpolationpixels(exampleinterpolationdata, spxt,
+#'                        as.Date(c("2001-02-03", "2001-06-03")))
+#'                        
+#' #Plot PET corresponding to 2001-06-03
+#' spplot(ml,2,"PET")
+#' 
+#' ####### INTERPOLATION over a complete GRID 
+#' #Interpolation of meteorology over a grid for two days
+#' ml = interpolationgrid(exampleinterpolationdata, examplegridtopography,
+#'                        as.Date(c("2001-02-03", "2001-06-03")))
+#' #Plot PET corresponding to 2001-06-03
+#' spplot(ml,2,"PET")
+#' }
+#' 
+#' @export
 interpolationpoints<-function(object, points, dates = NULL,
-                              export=FALSE, exportDir = getwd(), exportFile = NULL, 
+                              export=FALSE, exportDir = getwd(), exportFile = NULL,
                               exportFormat = "meteoland/txt",
                               metadataFile = "MP.txt", verbose=TRUE) {
+  # deprecation warning
+  lifecycle::deprecate_warn(
+    when = "2.0.0", what = "interpolationpoints()", with = "interpolate_data()",
+    details = "Spatial_*_Topography and MetereologyInterpolationData classes are soft deprecated.
+    Interpolator should be created with create_meteo_interpolator(),
+    and spatial objects to interpolate should be from sf (vector) or star (raster) classes.
+    Interpolation is performed with interpolate_data()"
+  )
+
   if(export) exportFormat = match.arg(exportFormat, c("meteoland/txt", "meteoland/rds", "castanea/txt", "castanea/rds", "netCDF"))
-  
+
   if(!inherits(object,"MeteorologyInterpolationData")) stop("'object' has to be of class 'MeteorologyInterpolationData'.")
   if(!inherits(points,"SpatialPointsTopography")) stop("'points' has to be of class 'SpatialPointsTopography'.")
   intpoints = as(points, "SpatialPoints")
@@ -158,7 +286,7 @@ interpolationpoints<-function(object, points, dates = NULL,
   }
   if(!is.null(dates)) {
     if(!inherits(dates,"Date")) stop("'dates' has to be of class 'Date'.")
-    if(sum(as.character(dates) %in% as.character(object@dates))<length(dates)) 
+    if(sum(as.character(dates) %in% as.character(object@dates))<length(dates))
       stop("At least one of the dates is outside the time period for which interpolation is possible.")
   }
   cc = coordinates(intpoints) #
@@ -174,14 +302,14 @@ interpolationpoints<-function(object, points, dates = NULL,
   longlat = spTransform(points,CRS(SRS_string = "EPSG:4326"))
   latitude = longlat@coords[,2]
   bbox = object@bbox
-  
-  
+
+
   if(exportFormat %in% c("meteoland/txt","castanea/txt")) formatType = "txt"
   else if (exportFormat %in% c("meteoland/rds","castanea/rds")) formatType = "rds"
   else if (exportFormat %in% c("netCDF")) formatType = "netCDF"
-  
+
   # Define vector of data frames
-  
+
   if(export & exportFormat %in% c("meteoland/txt","castanea/txt", "meteoland/rds","castanea/rds")) {
     dfout = data.frame(dir = rep(exportDir, npoints), filename=paste0(ids,".", formatType))
     dfout$dir = as.character(dfout$dir)
