@@ -1,4 +1,16 @@
+#' @describeIn interpolation.cv `r lifecycle::badge("deprecated")`
+#' @method plot interpolation.cv
+#' @exportS3Method plot interpolation.cv
 plot.interpolation.cv<-function(x, type="stations",...) {
+
+  # deprecation notice
+  lifecycle::deprecate_warn(
+    when = "2.0.0", what = "plot.interpolation.cv()", with = "interpolation_cross_validation()",
+    details = "interpolation_cross_validation() returns a list with the cross validation results for
+    dates and for stations. List elements are data frames that can be plotted in the usual ways (plot, ggplot2...)"
+  )
+
+
   type = match.arg(type, c("stations", "dates"))
   if(type =="stations") {
     stationsdf = x$stations
